bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.broadcasting_multiplier
=======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.broadcasting_multiplier